==> mingw-w64-clang-i686-libkml-1.3.0-9-any.pkg.tar.zst: clang32/lib/cmake/libkml/LibKMLTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kmlbase" for configuration "Release"
set_property(TARGET kmlbase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlbase PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlbase.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "D:/a/_temp/msys/msys64/clang32/lib/libexpat.dll.a;D:/a/_temp/msys/msys64/clang32/lib/libz.dll.a;D:/a/_temp/msys/msys64/clang32/lib/libminizip.dll.a;D:/a/_temp/msys/msys64/clang32/lib/liburiparser.dll.a;D:/a/_temp/msys/msys64/clang32/lib/libexpat.dll.a"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlbase.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS kmlbase )
list(APPEND _IMPORT_CHECK_FILES_FOR_kmlbase "/clang32/lib/libkmlbase.dll.a" "/clang32/bin/libkmlbase.dll" )

# Import target "kmldom" for configuration "Release"
set_property(TARGET kmldom APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmldom PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmldom.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmldom.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS kmldom )
list(APPEND _IMPORT_CHECK_FILES_FOR_kmldom "/clang32/lib/libkmldom.dll.a" "/clang32/bin/libkmldom.dll" )

# Import target "kmlxsd" for configuration "Release"
set_property(TARGET kmlxsd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlxsd PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlxsd.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlxsd.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS kmlxsd )
list(APPEND _IMPORT_CHECK_FILES_FOR_kmlxsd "/clang32/lib/libkmlxsd.dll.a" "/clang32/bin/libkmlxsd.dll" )

# Import target "kmlengine" for configuration "Release"
set_property(TARGET kmlengine APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlengine PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlengine.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase;kmldom"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlengine.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS kmlengine )
list(APPEND _IMPORT_CHECK_FILES_FOR_kmlengine "/clang32/lib/libkmlengine.dll.a" "/clang32/bin/libkmlengine.dll" )

# Import target "kmlconvenience" for configuration "Release"
set_property(TARGET kmlconvenience APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlconvenience PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlconvenience.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlengine;kmldom;kmlbase"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlconvenience.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS kmlconvenience )
list(APPEND _IMPORT_CHECK_FILES_FOR_kmlconvenience "/clang32/lib/libkmlconvenience.dll.a" "/clang32/bin/libkmlconvenience.dll" )

# Import target "kmlregionator" for configuration "Release"
set_property(TARGET kmlregionator APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlregionator PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlregionator.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase;kmldom;kmlengine;kmlconvenience"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlregionator.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS kmlregionator )
list(APPEND _IMPORT_CHECK_FILES_FOR_kmlregionator "/clang32/lib/libkmlregionator.dll.a" "/clang32/bin/libkmlregionator.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-i686-libkml-1.3.0-10-any.pkg.tar.zst: clang32/lib/cmake/libkml/LibKMLTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kmlbase" for configuration "Release"
set_property(TARGET kmlbase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlbase PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlbase.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "D:/a/msys64/clang32/lib/libexpat.dll.a;D:/a/msys64/clang32/lib/libz.dll.a;D:/a/msys64/clang32/lib/libminizip.dll.a;D:/a/msys64/clang32/lib/liburiparser.dll.a;D:/a/msys64/clang32/lib/libexpat.dll.a"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlbase.dll"
  )

list(APPEND _cmake_import_check_targets kmlbase )
list(APPEND _cmake_import_check_files_for_kmlbase "/clang32/lib/libkmlbase.dll.a" "/clang32/bin/libkmlbase.dll" )

# Import target "kmldom" for configuration "Release"
set_property(TARGET kmldom APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmldom PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmldom.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmldom.dll"
  )

list(APPEND _cmake_import_check_targets kmldom )
list(APPEND _cmake_import_check_files_for_kmldom "/clang32/lib/libkmldom.dll.a" "/clang32/bin/libkmldom.dll" )

# Import target "kmlxsd" for configuration "Release"
set_property(TARGET kmlxsd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlxsd PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlxsd.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlxsd.dll"
  )

list(APPEND _cmake_import_check_targets kmlxsd )
list(APPEND _cmake_import_check_files_for_kmlxsd "/clang32/lib/libkmlxsd.dll.a" "/clang32/bin/libkmlxsd.dll" )

# Import target "kmlengine" for configuration "Release"
set_property(TARGET kmlengine APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlengine PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlengine.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase;kmldom"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlengine.dll"
  )

list(APPEND _cmake_import_check_targets kmlengine )
list(APPEND _cmake_import_check_files_for_kmlengine "/clang32/lib/libkmlengine.dll.a" "/clang32/bin/libkmlengine.dll" )

# Import target "kmlconvenience" for configuration "Release"
set_property(TARGET kmlconvenience APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlconvenience PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlconvenience.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlengine;kmldom;kmlbase"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlconvenience.dll"
  )

list(APPEND _cmake_import_check_targets kmlconvenience )
list(APPEND _cmake_import_check_files_for_kmlconvenience "/clang32/lib/libkmlconvenience.dll.a" "/clang32/bin/libkmlconvenience.dll" )

# Import target "kmlregionator" for configuration "Release"
set_property(TARGET kmlregionator APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(kmlregionator PROPERTIES
  IMPORTED_IMPLIB_RELEASE "/clang32/lib/libkmlregionator.dll.a"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "kmlbase;kmldom;kmlengine;kmlconvenience"
  IMPORTED_LOCATION_RELEASE "/clang32/bin/libkmlregionator.dll"
  )

list(APPEND _cmake_import_check_targets kmlregionator )
list(APPEND _cmake_import_check_files_for_kmlregionator "/clang32/lib/libkmlregionator.dll.a" "/clang32/bin/libkmlregionator.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
